@@ -3,24 +3,24 @@
 #' Calculates likelihoods for relationship inference involving mixtures and missing reference profiles,
 #' including drop-in and dropout, mutations, silent alleles and theta correction.
 #'
-#' @param pedigrees A list of pedigrees defined using FamiliasPedigree in Familias
-#' @param locus A Familias locus. Note that a silent allele must be indicated by 's' (and not 'silent' as in Familias)
+#' @param pedigrees A list of pedigrees defined using \code{\link{FamiliasPedigree}}
+#' @param locus A list of class \code{\link{FamiliasLocus}} containing information about the locus. Note that a silent allele must be indicated by 's' (and not 'silent' as in Familias)
 #' @param R A vector of mixture alleles, or a list of such if there are multiple replicates
-#' @param datamatrix Each line corresponds to one constellation of genotypes for the involved individuals.
+#' @param datamatrix A data frame where each line corresponds to one constellation of genotypes for the involved individuals.
 #'  Indices of individuals must be given as rownames and must correspond to indices in the pedigree
-#' @param ids  Index vector indicating which individuals are contributors to the mixture. The indices must correspond to
+#' @param ids Index vector indicating which individuals are contributors to the mixture. The indices must correspond to
 #'  indices in the pedigree
-#' @param D List of dropout values (between 0 and 1) per contributor.
+#' @param D List of numeric dropout values (between 0 and 1) per contributor.
 #'  Each element is a vector containing heterozygous and homozygous dropout probability for the given contributor
-#' @param di Drop-in value (between 0 and 1)
-#' @param kinship Defines the theta-parameter
-#' @return The likelihoods for the pedigrees and detailed output for each term considered in the calculation.
-#' @details The function requires the package \pkg{Familias} and calls on the function \code{FamiliasPedigree}.
-#' @references Dorum et al. (2017) Pedigree-based relationship inference from complex DNA mixtures, Int J Legal Med., doi:10.1007/s00414-016-1526-x; \cr
-#' Kaur et al. (2016) Relationship inference based on DNA mixtures, Int J Legal Med.;130(2):323-9; \cr
-#' Egeland, Kling, Mostad (2015) \pkg{Familias}
+#' @param di A numeric drop-in value (between 0 and 1)
+#' @param kinship A numeric value between 0 and 1 that defines the theta-parameter
+#' @return A numeric likelihood for each pedigree named according to the pedigrees, and a matrix of likelihoods for each pedigree and each term (genotype constellation) considered in the calculation
+#' (one row per term).
+#' @details The function requires the package \code{\link{Familias}} and calls on the function \code{\link{FamiliasPosterior}}.
+#' @references Dorum et al. (2017) <doi:10.1007/s00414-016-1526-x> \cr
+#' Kaur et al. (2016) <doi:10.1007/s00414-015-1276-1> \cr
 #' @author Navreet Kaur, Thore Egeland, Guro Dorum
-#' @seealso \code{\link{relMixGUI}} for a relMix GUI, and \code{\link{FamiliasLocus}} on how to create a Familias locus.
+#' @seealso \code{\link{relMixGUI}} for the GUI version of relMix, \code{\link{FamiliasLocus}} on how to create a FamiliasLocus and \code{\link{FamiliasPedigree}} on how to create a FamiliasPedigree.
 #' @examples #Example 1: paternity trio with mixture of mother and child
 #' #Define alleles and frequencies
 #' alleles <- 1:2
@@ -95,23 +95,23 @@
 #' @export
 relMix <- function(pedigrees, locus, R, datamatrix, ids, D=rep(list(c(0,0)),length(ids)),di=0, kinship=0){
 
-  if(class(pedigrees)=='list'){
+  if(inherits(pedigrees,'list')){
       for (i in 1:length(pedigrees)) {
-        if (class(pedigrees[[i]]) != "FamiliasPedigree")
+        if (!inherits(pedigrees[[i]], "FamiliasPedigree"))
           stop("Argument pedigrees should be a list of Familias pedigrees")
 
         if(any(sapply(pedigrees,function(x) any(!ids%in%x$id))))
             stop("Argument ids does not correspond with indices in pedigree")
     }
   }else {
-    if(class(pedigrees) != "FamiliasPedigree")
+    if(!inherits(pedigrees, "FamiliasPedigree"))
       stop("Argument pedigrees should be a list of Familias pedigrees")
 
     if(any(!ids%in%pedigrees$id))
       stop("Argument ids does not correspond with indices in pedigree")
   }
-  if(class(R) != "list") R <- list(R)
-  if (class(locus) != "FamiliasLocus")
+  if(!inherits(R,"list")) R <- list(R)
+  if (!inherits(locus, "FamiliasLocus"))
     stop("Argument locus should be a Familias locus")
   if (!is.data.frame(datamatrix))
     stop("Argument datamatrix should be a dataframe")
